==> haskell-hslua-module-zip-1.1.1-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.1.1
visibility:           public
id:                   hslua-module-zip-1.1.1-HvaixaBUfy11YKAWOrrFB9
key:                  hslua-module-zip-1.1.1-HvaixaBUfy11YKAWOrrFB9
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  97ef41ebb1ea7906ee42e98c49b1f3c4
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.1-HvaixaBUfy11YKAWOrrFB9
depends:
    base-4.17.2.1 bytestring-0.11.5.3 filepath-1.4.2.2
    hslua-core-2.3.1-LsngH4WuUwlC1Ml0x0LYBs
    hslua-list-1.1.3-E7NtmTd5XLjDiHSs6b7CIp
    hslua-marshalling-2.3.1-9mmGA2NSwpxIKMAzIMvWOU
    hslua-packaging-2.3.1-IdUcqfnuqcrEsyMEkQWyQv
    hslua-typing-0.1.1-4VNr04A0Bkw3I9DIDZSF6c text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-GmNVaBYgl1m3nPxjZ1tNrn

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-zip-1.1.1-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.1.1
visibility:           public
id:                   hslua-module-zip-1.1.1-ET8sF18v9Nr1kdneeB7lBH
key:                  hslua-module-zip-1.1.1-ET8sF18v9Nr1kdneeB7lBH
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  e9b266a7649e8a98dca27afe8ff5f139
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.1-ET8sF18v9Nr1kdneeB7lBH
depends:
    base-4.17.2.1 bytestring-0.11.5.3 filepath-1.4.2.2
    hslua-core-2.3.1-KHtQ1StPUFGgDZgoD7E0A
    hslua-list-1.1.3-D0OsRlpSaMK4a4SfYcace
    hslua-marshalling-2.3.1-IgtCsiHhYGy5iz5DZtbSV9
    hslua-packaging-2.3.1-9uoqvhTbA4947oSISrR4wL
    hslua-typing-0.1.1-6dwcqeowJntEVSsqZCTn0F text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-GmNVaBYgl1m3nPxjZ1tNrn

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
